%{
/* config.yacc -- config file parser.
 * Dean Collins
 * created: Mon Aug 24 23:45:28 PDT 1992
 */

/*
 * Copyright (c) 1992 Dean Collins.
 * Copyright (c) 1992 University of Idaho, Moscow, Idaho.
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation free of charge for any purpose is hereby granted without
 * fee, provided that the above copyright notices appear in all copies and
 * that both those copyright notices and this permission notice appear in
 * supporting documentation, and that neither the name of the University of
 * Idaho nor the name of Dean Collins be used in advertising or publicity
 * pertaining to distribution of the software without specific, written
 * prior permission from both parties.  Neither The University of Idaho
 * nor Dean Collins make any representations about the suitability of
 * this software for any purpose.  It is provided "as is" without express
 * or implied warranty.
 * 
 * THE UNIVERSITY OF IDAHO AND DEAN COLLINS DISCLAIM ALL WARRANTIES WITH
 * REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS.  IN NO EVENT SHALL THE UNIVERSITY OF IDAHO
 * OR DEAN COLLINS BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
 * DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
 * PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
 * ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 * THIS SOFTWARE.
 */

/* Includes here */
#include <stdio.h>
#include "zdbm.h"
#include "cloud.h"
#include "config.h"
#ifdef DEBUG
#include "errno.h"
#endif

/* OK, they really aren't the same. Should work anyhow. This is done since
 * our version of bison on our HP-UX machines generates a y.tab.c file with
 * calls to alloca().  Probably means our bison is screwy.  Oh, well.
 * This will work until bison is fixed.  The regular yacc works ok, too.
 */
#ifdef HPUX
#define alloca(s) malloc(s)
#endif


/* variable decs. here. */
extern int debug ;
extern char ParserPath[] ;
extern char ParserName[] ;
extern int ParserDays ;
extern FILE *yyin ; /* From lex.yy.c */

int parsetype=0 ;
struct Full_path *CfgTree=NULL ;
MailInfo *CfgMailList=NULL ;
int parse_error=0 ;

%}

/* List of all possible tokens... */
%token EOL WS INT NAME PATH

%%
configfile	: validline            { if (debug) printf("<configfile>") ; }
		| validline configfile { if (debug) printf("<configfile>") ; }

validline	: pathline {if (debug) printf("<validline>") ;}
		| mailline {if (debug) printf("<validline>") ;}
		| eol      {if (debug) printf("<validline>") ;}
		| badline  {if (debug) printf("<validline>") ;}

pathline	: path eol {if (debug) printf("\nYacc: pathline found\n") ;
			    if(parsetype == PARSEPATH)
			    {  if (debug)
                                  printf("Calling AddPath(CfgTree,\"%s\");\n",
				 	 ParserPath) ;
			       CfgTree = AddPath(CfgTree,ParserPath) ;
			    }
			   }

path		:    PATH {if (debug) printf("<path>") ;}
		| ws PATH {if (debug) printf("<path>") ;}

mailline	: name ws INT eol
		  {if (debug) printf("\nYacc: mailline found\n") ;
		    if(parsetype == PARSEMAIL)
		    {   if (debug)
                           printf("Calling AddMail(CfgMailList,\"%s\",%d);\n",
		                  ParserName, ParserDays) ;
			CfgMailList = AddMail(CfgMailList,ParserName,
					      ParserDays) ;
		    }
		  }

name		:    NAME {if (debug) printf("<name>") ;}
		| ws NAME {if (debug) printf("<name>") ;}
		
eol		:    EOL {if (debug) printf("<eol>") ;}
		| ws EOL {if (debug) printf("<eol>") ;}

ws		: WS    {if (debug) printf("<ws>") ;}
		| WS ws {if (debug) printf("<ws>") ;}

badline		: error EOL {fprintf(stderr, "Error in config file!\n");
			     parse_error++ ;
			    }

%%
/* Function defs here. */


/*
______________________________________________________________________
config_tree()

FUNCTION DESCRIPTION:

	Read the problem tree hierarchy.
______________________________________________________________________
UNIT TESTING:
     This function will be tested by using a combination of white-box and
black-box tests.
______________________________________________________________________
REVISION HISTORY:
     Author:  Dean Collins            Date:  6/92
______________________________________________________________________
*/


int
config_tree(struct Full_path **pathlist)

     /* Interface description:
         INPUT/OUTPUT:
          pathlist	- Ptr to ptr to head of Full_path linked list.
         RETURN VALUE:
          int		- Zero means success, non-zero means error.
     */

{ 
     /* Internal variables: */
          /* Major */
          /* NONE  */
          /* Minor */
          /* NONE  */

   /*-------------- Start of config_tree() routine ---------------*/

	/* Open the configuration file for reading. */
/*   yyin = freopen(CONFIGFILE, "r", yyin) ;*/
   yyin = fopen(CONFIGFILE, "r") ;
   if (yyin == NULL)
   {   fprintf(stderr, "Error opening config file %s !\n", CONFIGFILE) ;
       return (-1) ;
   }

	/* Call the parser and have it build the tree. */
   parsetype=PARSEPATH ;
   parse_error=0 ;
   if (debug) printf("Beginning NEW & IMPROVED config file parse...\n") ;

   yyparse() ;

   if (debug) printf("\nEnding NEW & IMPROVED config file parse...\n") ;
   *pathlist = CfgTree ;

#ifdef DEBUG
/*CLD*/   TraverseList(CfgTree) ;
#endif

	/* Close the configuration file. */
   fclose(yyin) ;

   return(parse_error) ;

}  /*------------------ End of config_tree() ---------------------*/


/*
______________________________________________________________________
config_mail()

FUNCTION DESCRIPTION:

     Read the list of people to send mail to when problems are old.
______________________________________________________________________
UNIT TESTING:
     This function will be tested by using a combination of white-box and
black-box tests.
______________________________________________________________________
REVISION HISTORY:
     Author:  Dean Collins      Date:  6/92
______________________________________________________________________
*/

int
config_mail(MailInfo **maillist)

     /* Interface description:
         INPUT/OUTPUT:
	  maillist	- ptr to ptr to head of MailInfo linked list.
         RETURN VALUE:
          int           - Zero means success, non-zero means error.
     */

{
     /* Internal variables: */
          /* Major */
          /* NONE  */
          /* Minor */
          /* NONE  */


   /*----------------- Start of config_mail() routine ------------------*/

#ifdef DEBUG
   printf("Entered config_mail()\n") ;
#endif

	/* Open the configuration file for reading. */
   yyin = fopen(CONFIGFILE, "r") ;
   if (yyin == NULL)
   {   fprintf(stderr, "Error opening config file %s !\n", CONFIGFILE) ;
       return (-1) ;
   }
	/* Call the parser and have it build the mail list. */
   parsetype=PARSEMAIL;
   parse_error=0 ;
   if (debug) printf("Beginning NEW & IMPROVED config file parse...\n") ;

   yyparse() ;

   if (debug) printf("\nEnding NEW & IMPROVED config file parse...\n") ;
   *maillist = CfgMailList ;


	/* Close the configuration file. */
   fclose(yyin) ;

#ifdef DEBUG
   printf("Leaving config_mail(), list=%p\n",*maillist) ;
#endif

   return(parse_error) ;
}  /*--------------------- End of config_mail() ------------------------*/

/* end of config.yacc */

