.TH pts 1 "26 November 1993" "Zombie Software" "PTS version 1.03"
.SH NAME
PTS - Problem Tracking System
.br
.SH DESCRIPTION
.I PTS
is a database tool which is used to improve communication 
between system users and support personnel about problems encountered
with the system.  It consists of several programs, including
.I
xpts
and
.I
ptsager.
.PP
In a nutshell:  
.I xpts
is used by system users to report problems.  
Support personnel also use it to log their activities on solving
each problem.  
.I xpts 
also sends e-mail to problem reporters when their problems are solved.
.I
Ptsager
scans through the database once a day and sends electronic mail
to certain system users about problems that have remained unsolved for
several days.
.PP
While
.I PTS
was designed with managing a network of Unix workstations in mind,
It is general and versatile enough to be used in many
other ways.  For example, at the University of Idaho,
.I xpts
was used by the design team to report problems with
and take suggestions about early versions of
.I xpts.
We are very interested in hearing about unique and creative ways
in which you use
.I xpts.
.PP
.SH MORE INFORMATION
.I Much
more documentation is available.  The Software Requirements Specification
and the Software Design Document are available.  (see below)
[Note:  PTS version 1.03 is being distributed without the
complete SRS and SDD.  Future releases will include
the documentation as described.]
.SH DESIGN INFORMATION
Since
.I
PTS
was designed for the University of Idaho Computer Science Department
it was decided that not only were we after a completed product
but also we were after a learning tool -- a "real-world" example
of some of the techniques covered in class.  For this reason
PTS is distributed with the full and complete set of documentation
used to implement the package.
.SH Waterfall Design
.I PTS
was designed using the Iterative Waterfall Design Methodology.
This is a document-driven software design method.
.PP
This design methodology includes creating a
.I Software Requirements Specification
(SRS),
(also known as a Software Requirements Document (SRD).)  
For those unfamiliar with requirements specifications, an 
.I SRS
is used to specify
.I WHAT
the software needs to do to meet the customers needs.
It specifically does NOT say how to do it.  It doesn't even
say what language it will be implemented in.
.PP
This design methodology also includes creating a
.I Software Design Document
(SDD),
(also known as a Software Design Specification (SDS).)
For those unfamiliar with formal design documentation, an
.I SDD
is used to specify
.I HOW
the software will be designed, and how that design will
meet the requirements described in the
.I SRS.
.PP
The third part of the documentation for this methodology is
the code itself, which
should match the specified design as closely as possible.
If the specified design cannot be coded the design document
needs to be revised.
.PP
Finally, the fourth part of this methodology's documentation
is the users manual, which we have provided as Unix "man" pages.
.PP
.SH Design Overview
Briefly, 
.I PTS
is designed as
.I layered
software.
The bottom layer is
.I zdbm,
the Zombie Database Manager, and is documented more fully
in the zdbm manpage.
The top layer is the application layer.  One application is
.I xpts
another is
.I ptsager.
These applications process and modify data in the
.I PTS
database.
.PP
However, they do not deal directly with either
.I zdbm
or the database itself.
Between the application layer and the low-level database level
is, for the lack of a better name, "The Cloud", which manages
to isolate the applications from the details of the database.
.PP
This layered approached was originally done to keep from placing
too many design details about 
.I zdbm
in 
.I xpts.
Because of this layered approach, implementing other applications
is much simpler.  In fact, the bulk of 
.I ptsager
was designed and implemented in one weekend.
(I wish 
.I xpts 
had went that quickly!)
.PP
Another benefit of this layered approach is that the PTS system
is not married either to 
.I zdbm
or to
.I xpts.
In theory,
.I zdbm
could be completely redesigned and 
.I xpts
would require few, if any, changes.  
Conversely, the 
.I xpts
user-interface could easily be rewritten without any modifications to 
.I zdbm.
A crude, proof-of-concept, text-mode interface was implemented
taking advantage of this layered approach.
.PP
.SH Old Documents
In browsing through the 
.I PTS
documentation you will notice several versions of the
major documents.  This is, by definition, an
.I iterative
process.  
When creating the design document you may very well discover
oversights or other problems in your requirements documentation
so you iterate back and revise your requirements as needed.
Then you take another look at your design document with
this new set of requirements in mind and continue.
The iteration is not "bad", and in fact greatly improves
the quality of the package as a whole.
For this reason there are several versions of each of the
major documents.
.PP
.SH Disclaimers
The above discussion is a great over-simplification of the
Iterative Waterfall Design Methodology (with apologies to our professors!).
.PP
We in no way claim that this is the best way to design and implement software.
Others were considered such as Rapid Prototyping, but we chose this one.
It worked for us.
.PP
Nor do we claim that 
.I PTS
is a "perfect" example of this methodology.  In fact, we state
for the record that we have made some mistakes, most having to 
do with inexperience with designing such a large package 
(the version 1.01 implementation of PTS is over 25,000 lines long.)
However, we hope that others might learn from our mistakes as we have.
This was our chance to "learn by doing" and to gain some real experience.
We sincerly hope you find this instructive and in some way useful.
.PP
The opinions expressed in this man page and in all other
.I PTS
documentation are strictly those of the author(s) and in no way
constitute an official policy, statement, or other communication
of the University of Idaho, of the U. of I. Computer Science
Department, or of any of our professors or supervisors,
except where explicitly stated otherwise.
.PP
.I One final disclaimer:
Please don't get the idea that
.I PTS
was created strictly for the design processes as described above.
In the end, it had to work, and it does.  It was not written as part
of a class, but as part of our jobs.  It is "real" software
that really works.  Above all, we hope you find the software
itself useful, as the University of Idaho Computer Science Department does.
.PP
.SH FILES
/usr/local/lib/PTS --
.I  PTS
library files.
.br
/usr/local/lib/PTS/pts.cf --
.I  PTS
configuration file.
.br
/usr/local/lib/PTS/DB --
.I  PTS
database.
.br
/usr/lib/X11/xpts.help -- On-line help file for 
.I xpts.
.br
/usr/lib/X11/xpts_sysop.help -- On-line help file for the sysop menu.
.br
/usr/lib/X11/app-defaults/Xpts -- X Application Defaults file.
.SH SEE ALSO
ptsager(1M), xpts(1), pts.cf(8), zdbm(3).
.SH BUGS
There are no bugs.  Unexpected features, perhaps, but no bugs...
(However, we still haven't gotten around to implementing "feature X".)
.SH AUTHORS
The Problem Tracking System was designed by
.I Zombie Software
for the University of Idaho Computer Science Department
in Moscow, Idaho.
.I Zombie Software
is the self-proclaimed title collectively used by several students
and former students associated with the U. of I. Computer Science Department.
All have, at one time or another, been part of the support staff
for the Department's computing facilities.  Most were part of the
support staff during large portions of the development of
.I PTS.
However, another large portion of the development of
.I PTS
was done on a volunteer basis when off-duty or by non-employees.
.sp 1
.I Zombie Software
is:
.sp 1
.in 10n
Project Leader:
.sp 1
.in 15n
Dean Collins, Assistant System Manager
.in 20n
X11 user-interface design and implementation;
Configuration file parser design and implementation;
Software Requirements Document contributions;
.I ptsager
design and implementation.
.br
(Internet: dean@uidaho.edu, dean@cs.uidaho.edu)
.sp 1
.in 10n
Design Team Members:
.sp 1
.in 15n
Chris Hyde
.in 20n
zdbm database design and implementation;
Software Requirements Document contributions.
.br
(Internet: chyde@delphi.com)
.sp 1
.in 15n
Luke Sheneman
.in 20n
High-level database interface design and implementation;
Configuration file parser implementation contributions.
.br
(Internet: sheneman@snake.cs.uidaho.edu)
.sp 1
.in 15n
Brian Goff
.in 20n
.I ptsager
design and implementation;
Software Requirements Document contributions.
.br
(Internet: brian@snake.cs.uidaho.edu)
.sp 1
.in 15n
John Hunter
.in 20n
Software Requirements Document contributions;
Software Design Document contributions.
.br
(Internet: hunte874@snake.cs.uidaho.edu)
.sp 1
.in 15n
Brent Heikkila
.in 20n
Software Requirements Document contributions.
.sp 1
.in 15n
Dayne Steed
.in 20n
Software Requirements Document contributions.
.br
.sp 2
.in 5n
.I Zombie Software
can be contacted through the following Internet E-mail accounts:
.in 10n
.sp 1
.nf
dean@uidaho.edu 
dean@cs.uidaho.edu 
zombie@snake.cs.uidaho.edu
support@snake.cs.uidaho.edu
simon@cs.uidaho.edu
.fi
.sp 1
.SH COPYRIGHT
Copyright (c) 1993,1992 Dean Collins, Chris Hyde, Luke Sheneman, Brian Goff,
and John Hunter.
.br
Copyright (c) 1992 University of Idaho, Moscow, Idaho.

